@@ -1,8 +1,9 @@
 package Net::Cisco::FMC::v1;
-$Net::Cisco::FMC::v1::VERSION = '0.006001';
+$Net::Cisco::FMC::v1::VERSION = '0.006002';
 # ABSTRACT: Cisco Firepower Management Center (FMC) API version 1 client library
 
 use 5.024;
+use utf8;
 use Moo;
 use feature 'signatures';
 use Types::Standard qw( ArrayRef Dict Str );
@@ -466,7 +467,10 @@ sub cleanup_hosts($self) {
 }
 
 
-sub create_cleaned_accesspolicy (    $self,    $source_accesspolicy_name,    $optional = {}) {
+sub create_cleaned_accesspolicy (
+    $self,
+    $source_accesspolicy_name,
+    $optional = {}) {
     my $destination_accesspolicy_name = exists $optional->{target_access_policy_name}
         ? $optional->{target_access_policy_name}
         : $source_accesspolicy_name . '-cleaned';
@@ -678,7 +682,7 @@ Net::Cisco::FMC::v1 - Cisco Firepower Management Center (FMC) API version 1 clie
 
 =head1 VERSION
 
-version 0.006001
+version 0.006002
 
 =head1 SYNOPSIS
 
@@ -883,7 +887,7 @@ Alexander Hartmaier <abraxxa@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 - 2020 by Alexander Hartmaier.
+This software is copyright (c) 2018 - 2022 by Alexander Hartmaier.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
